Stan Math Library: stan/math/rev/mat/functor/cvodes_ode_data.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
cvodes_ode_data.hpp File Reference
`#include <stan/math/rev/mat/functor/ode_system.hpp>`
`#include <stan/math/rev/scal/meta/is_var.hpp>`
`#include <cvodes/cvodes.h>`
`#include <cvodes/cvodes_band.h>`
`#include <cvodes/cvodes_dense.h>`
`#include <nvector/nvector_serial.h>`
`#include <algorithm>`
`#include <vector>`

Go to the source code of this file.

## Classes
class | stan::math::cvodes_ode_data< F, T_initial, T_param >
| CVODES ode data holder object which is used during CVODES integration for CVODES callbacks. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.